macro_rules! log_enabled {
($level:expr) => { ... };
}Expand description
Returns true if a message at the given level would be logged.
Checks both the compile-time STATIC_MAX_LEVEL and the runtime
max_level filters.
macro_rules! log_enabled {
($level:expr) => { ... };
}Returns true if a message at the given level would be logged.
Checks both the compile-time STATIC_MAX_LEVEL and the runtime
max_level filters.